/*
Product name : MepL_Farm PCB_ver
Board : Arduino_Micro 
MCU : BuiltIn(ATMEGA32U4-MU)


//---- 센서의 핀 설계
  Neopixel_Led_Pin  number is   5 
  Buzzer_pin        number is   6 (BuiltIn)
  Led_pin           number is   13(BuiltIn)
  Button_pin        number is   A0(BuiltIn)
  Soil_Sensor       number is   A1
  DHTPIN            number is   A2
  Cds               number is   A3
  Fan A_Front       number is   7       // 쿨링팬 왼쪽   A의 전진방향
  Fan A_Back        number is   4       // 쿨링팬 왼쪽   A의 후진방향
  Fan A_Front       number is   8       // 쿨링팬 오른쪽 B의 전진방향
  Fan A_Back        number is   12      // 쿨링팬 오른쪽 B의 후진방향
  TouchPins[4]      number is   {11,14,15,16}
*/

#include <Adafruit_NeoPixel.h>
#include <LiquidCrystal_I2C.h>

#define Cds A3              // 조도센서 핀
#define pixelsPin 5         // NeoPixel 핀
#define numPixels 8         // NeoPixel 개수

LiquidCrystal_I2C lcd(0x27, 16, 2); 
Adafruit_NeoPixel pixels(numPixels, pixelsPin, NEO_GRB + NEO_KHZ800);

void setup() {
  Serial.begin(9600);

  // 조도센서 핀 입력 설정
  pinMode(Cds, INPUT);

  // LCD 초기화
  lcd.init();
  lcd.backlight();
  lcd.clear();

  // NeoPixel 초기화
  pixels.begin();
  pixels.setBrightness(50); // 밝기 조절
  pixels.clear();
  pixels.show();
}

void loop() {
  int cdsValue = analogRead(Cds); 
  // 조도센서 값 읽기 (0~1023)

  Serial.print("조도 센서 값: ");
  Serial.println(cdsValue);

  lcd.clear();
  lcd.setCursor(0, 0);

  if (cdsValue > 400) { // 어두운 경우
    lcd.print("Turn on light");
    lcd.setCursor(0, 1);
    lcd.print("LED ON!");

    // 흰색으로 네오픽셀 켜기
    for (int i = 0; i < numPixels; i++) {
      pixels.setPixelColor(i, pixels.Color(255, 255, 255));
    }
  } else { // 밝은 경우
    lcd.print("Turn off light");
    lcd.setCursor(0, 1);
    lcd.print("LED OFF!");

    // 초록색으로 네오픽셀 켜기
    for (int i = 0; i < numPixels; i++) {
      pixels.setPixelColor(i, pixels.Color(0, 0, 0));
    }
  }

  pixels.show(); // 변경된 색상 적용
  delay(1000);
}



