/*
Product name : MepL_Farm PCB_ver
Board : Arduino_Micro 
MCU : BuiltIn(ATMEGA32U4-MU)


//---- 센서의 핀 설계
  Neopixel_Led_Pin  number is   5 
  Buzzer_pin        number is   6 (BuiltIn)
  Led_pin           number is   13(BuiltIn)
  Button_pin        number is   A0(BuiltIn)
  Soil_Sensor       number is   A1
  DHTPIN            number is   A2
  Cds               number is   A3
  Fan A_Front       number is   7       // 쿨링팬 왼쪽   A의 전진방향
  Fan A_Back        number is   4       // 쿨링팬 왼쪽   A의 후진방향
  Fan A_Front       number is   8       // 쿨링팬 오른쪽 B의 전진방향
  Fan A_Back        number is   12      // 쿨링팬 오른쪽 B의 후진방향
  TouchPins[4]      number is   {11,14,15,16}
*/

#include <Adafruit_NeoPixel.h>

#define LED_PIN 5         // 네오픽셀 제어 핀
#define numPixels 8       // 네오픽셀 LED 개수
Adafruit_NeoPixel pixels(numPixels, LED_PIN, NEO_GRB + NEO_KHZ800);

int touchPins[4] = {11, 14, 15, 16}; // TTP224 터치센서 출력 핀

void setup() {
  for (int i = 0; i < 4; i++) {
    pinMode(touchPins[i], INPUT);
  }

  pixels.begin();
  pixels.clear();
  pixels.show();

  Serial.begin(9600);
}

void loop() {
  for (int i = 0; i < 4; i++) {
    if (digitalRead(touchPins[i]) == HIGH) {
      Serial.print("Touch Detected: ");
      Serial.println(i + 1);
      setColor(i + 1);
      delay(300); // 디바운스
    }
  }
}

// 버튼 번호에 따른 네오픽셀 전체 색상 설정
void setColor(int buttonNum) {
  uint32_t color;
  switch (buttonNum) {
    case 1:
      color = pixels.Color(255, 0, 0);   // 빨강
      break;
    case 2:
      color = pixels.Color(0, 255, 0);   // 초록
      break;
    case 3:
      color = pixels.Color(0, 0, 255);   // 파랑
      break;
    case 4:
      color = pixels.Color(0, 0, 0); // 노랑
      break;
    default:
      color = pixels.Color(0, 0, 0);     // 끔
      break;
  }

  for (int i = 0; i < numPixels; i++) {
    pixels.setPixelColor(i, color);
  }
  pixels.show();
}
