/*
Product name : MepL_Farm PCB_ver
Board : Arduino_Micro 
MCU : BuiltIn(ATMEGA32U4-MU)


//---- 센서의 핀 설계
  Neopixel_Led_Pin  number is   5 
  Buzzer_pin        number is   6 (BuiltIn)
  Led_pin           number is   13(BuiltIn)
  Button_pin        number is   A0(BuiltIn)
  Soil_Sensor       number is   A1
  DHTPIN            number is   A2
  Cds               number is   A3
  Fan A_Front       number is   7       // 쿨링팬 왼쪽   A의 전진방향
  Fan A_Back        number is   4       // 쿨링팬 왼쪽   A의 후진방향
  Fan A_Front       number is   8       // 쿨링팬 오른쪽 B의 전진방향
  Fan A_Back        number is   12      // 쿨링팬 오른쪽 B의 후진방향
  TouchPins[4]      number is   {11,14,15,16}
*/

#include <LiquidCrystal_I2C.h>
#include "DHT.h"

// DHT 센서 핀 정의
#define DHTPIN A2
// DHT 센서의 종류
#define DHTTYPE DHT11
// 토양 온습도 센서 핀 번호
#define Soil_Sensor A1

// set the LCD address to 0x27(0x3F) 
// for a 16 chars and 2 line display
LiquidCrystal_I2C lcd(0x27, 16, 2); 
// 정의된 핀과 센서 유형으로 dht 객체 생성
DHT dht(DHTPIN, DHTTYPE);

//----------------------------------------------------------------------
// 부팅시 만 실행
void setup()  {
  // 시리얼통신 초기화(9600)bps(bits per second)
  Serial.begin(9600);
  // LCD 초기화 
  lcd.init();
  // 백라이트 활성화
  lcd.backlight();
  // LCD 화면 지우기
  lcd.clear();
  // 온습도센서를 초기화 합니다.
  dht.begin();
}

void loop()  {
  delay(2000);
  // 습도와 온도 값을 측정하여 읽어옵니다.(h는 습도, t는 온도)
  int h = dht.readHumidity();
  int t = dht.readTemperature();
  // 토양 온습도 센서의 값을 읽어옴
  int soilSensorValue = analogRead(Soil_Sensor);
  //LCD 화면 지우기
  lcd.clear();
  //0행 0열 커서위치
  lcd.setCursor(0,0);
  lcd.print("H:");
  lcd.print(h);
  lcd.print("%, ");
  //연속하여 프린트 
  lcd.print("T:");
  lcd.print(t);
  lcd.print("C");
  //1행 0열 커서위치 
  lcd.setCursor(0,1);
  lcd.print("Soil_value:");
  lcd.print(soilSensorValue);
}
