/*
Product name : MepL_Farm PCB_ver
Board : Arduino_Micro 
MCU : BuiltIn(ATMEGA32U4-MU)


//---- 센서의 핀 설계
  Neopixel_Led_Pin  number is   5 
  Buzzer_pin        number is   6 (BuiltIn)
  Led_pin           number is   13(BuiltIn)
  Button_pin        number is   A0(BuiltIn)
  Soil_Sensor       number is   A1
  DHTPIN            number is   A2
  Cds               number is   A3
  Fan A_Front       number is   7       // 쿨링팬 왼쪽   A의 전진방향
  Fan A_Back        number is   4       // 쿨링팬 왼쪽   A의 후진방향
  Fan A_Front       number is   8       // 쿨링팬 오른쪽 B의 전진방향
  Fan A_Back        number is   12      // 쿨링팬 오른쪽 B의 후진방향
  TouchPins[4]      number is   {11,14,15,16}
*/

#include <Adafruit_NeoPixel.h>
#include <LiquidCrystal_I2C.h>
#include "DHT.h"

// DHT 센서 핀 정의
#define DHTPIN A2
// DHT 센서의 종류
#define DHTTYPE DHT11
// 토양 온습도 센서 핀 번호
#define Soil_Sensor A1
#define A_Front  7      // 쿨링팬 왼쪽   A의 전진방향
#define A_Back   4      // 쿨링팬 왼쪽   A의 후진방향
#define B_Front  8      // 쿨링팬 오른쪽 B의 전진방향
#define B_Back  12      // 쿨링팬 오른쪽 B의 후진방향
#define numPixels 8     // 스트립 개수
#define pixelsPin 5     // PWM 핀번호 사용

LiquidCrystal_I2C lcd(0x27, 16, 2); 
// 정의된 핀과 센서 유형으로 dht 객체 생성
DHT dht(DHTPIN, DHTTYPE);
// (NEO_GRB + NEO_KHZ800): 색상 형식과 통신 속도를 지정
Adafruit_NeoPixel pixels(numPixels, pixelsPin, NEO_GRB + NEO_KHZ800);

//----------------------------------------------------------------------
// 부팅시 만 실행
void setup()  {
  // 시리얼통신 초기화(9600)bps
  Serial.begin(9600);
  // LCD 초기화 
  lcd.init();
  // 백라이트 활성화
  lcd.backlight();
  // LCD 화면 지우기
  lcd.clear();
  // 온습도센서를 초기화 합니다.
  dht.begin();

  pinMode(A_Front, OUTPUT);
  pinMode(A_Back, OUTPUT);
  pinMode(B_Front, OUTPUT);
  pinMode(B_Back, OUTPUT);  
  pixels.begin();
  // 밝기는 0에서 255까지의 값을 가짐
  pixels.setBrightness(10); 
  pixels.clear();
}

void loop()
{
  delay(2000);
  // h는 습도, t는 온도
  int h = dht.readHumidity();
  int t = dht.readTemperature();
 
  //LCD 화면 지우기
  lcd.clear();

  // 온도를 확인하여 값을 적절히 변경하기
  if(t < 23)  {
   //0행 0열 커서위치
    lcd.setCursor(0,0);
    lcd.print("T:");
    lcd.print(t);
    lcd.print("C, It's Cold");
    //1행 0열 커서위치 
    lcd.setCursor(0,1);
    lcd.print("Light ON!");

    for(int i=0; i<8; i++)  {
      pixels.setPixelColor(i,255,0,0);
      pixels.show();
    }
  }
  else  {
    for(int i=0; i<8; i++)  {
      pixels.setPixelColor(i,0,0,0);
      pixels.show();
    }

    lcd.clear();
    lcd.setCursor(0,0);
    lcd.print("T:");
    lcd.print(t);
    lcd.print("C, ");
    lcd.print("Light OFF!");
    lcd.setCursor(0,1);
    lcd.print("Optimal temp!");
  }
}
