/*
Product name : MepL_Farm PCB_ver
Board : Arduino_Micro 
MCU : BuiltIn(ATMEGA32U4-MU)


//---- 센서의 핀 설계
  Neopixel_Led_Pin  number is   5 
  Buzzer_pin        number is   6 (BuiltIn)
  Led_pin           number is   13(BuiltIn)
  Button_pin        number is   A0(BuiltIn)
  Soil_Sensor       number is   A1
  DHTPIN            number is   A2
  Cds               number is   A3
  Fan A_Front       number is   7       // 쿨링팬 왼쪽   A의 전진방향
  Fan A_Back        number is   4       // 쿨링팬 왼쪽   A의 후진방향
  Fan A_Front       number is   8       // 쿨링팬 오른쪽 B의 전진방향
  Fan A_Back        number is   12      // 쿨링팬 오른쪽 B의 후진방향
  TouchPins[4]      number is   {11,14,15,16}
*/

#include <Adafruit_NeoPixel.h>
#include <LiquidCrystal_I2C.h>
#include "DHT.h"

#define DHTPIN A2
#define DHTTYPE DHT11
#define Soil_Sensor A1
#define Cds A3
#define A_Front  7
#define A_Back   4
#define B_Front  8
#define B_Back  12
#define numPixels 8
#define pixelsPin 5
#define Buzzer_pin 6
#define Button_pin A0
#define Led_pin 13

int touchPins[4] = {11, 14, 15, 16};
int FAN_state = 0;
int NEO_LED_state = 0;
int LCD_state = 0;
int touchLastState[4] = {0, 0, 0, 0};

LiquidCrystal_I2C lcd(0x27, 16, 2); 
DHT dht(DHTPIN, DHTTYPE);
Adafruit_NeoPixel pixels(numPixels, pixelsPin, NEO_GRB + NEO_KHZ800);

void setup()  {
  Serial.begin(9600);

  dht.begin();
  pinMode(Buzzer_pin, OUTPUT); 
  pinMode(Led_pin, OUTPUT); 
  pinMode(Cds, INPUT);

  for (int i = 0; i < 4; i++) {
    pinMode(touchPins[i], INPUT);
  }

  lcd.init();
  lcd.backlight();
  lcd.clear();
  lcd.setCursor(0,0); lcd.print("Meple_SmartFarm!");

  pixels.begin();
  pixels.setBrightness(10); 
  pixels.clear();  
  pixels.show();
}

void loop() {
  for (int i = 0; i < 4; i++) {
    int currentState = digitalRead(touchPins[i]);
    if (currentState == HIGH && touchLastState[i] == LOW) {
      Serial.print("Touch Detected: "); Serial.println(i+1);

      switch (i) {
        case 0: // 1번 터치 - FAN 토글
          FAN_state = !FAN_state;
          if (FAN_state == 1) {
            // 모터 A를 전진 방향으로 회전
            digitalWrite(A_Front, LOW);
            digitalWrite(A_Back, HIGH);
            // 모터 B를 전진 방향으로 회전
            digitalWrite(B_Front, HIGH);
            digitalWrite(B_Back, LOW);
          } else {
            // 모터 A와 모터 B를 정지
            digitalWrite(A_Front, LOW);
            digitalWrite(A_Back, LOW);
            digitalWrite(B_Front, LOW);
            digitalWrite(B_Back, LOW);
          }
          break;

        case 1: // 2번 터치 - 네오픽셀 토글
          NEO_LED_state = !NEO_LED_state;
          for (int j = 0; j < 8; j++) {
            pixels.setPixelColor(j, NEO_LED_state ? pixels.Color(255,255,0) : pixels.Color(0,0,0));
          }
          pixels.show();
          break;

        case 2: { // 3번 터치 - 온습도 LCD 출력
          int h = dht.readHumidity();
          int t = dht.readTemperature();
          lcd.clear();
          lcd.setCursor(0,0); lcd.print("H:"); lcd.print(h); lcd.print("% T:"); lcd.print(t); lcd.print("C");
          break;
        }

        case 3: { // 4번 터치 - 토양수분 LCD 출력
          int soil = analogRead(Soil_Sensor);
          lcd.clear();
          lcd.setCursor(0,0); lcd.print("Soil Moisture");
          lcd.setCursor(0,1); lcd.print("Value:"); lcd.print(soil);
          break;
        }
      }
    }
    touchLastState[i] = currentState;
  }

  delay(50);
}
