/*
Product name : MepL_Farm PCB_ver
Board : Arduino_Micro 
MCU : BuiltIn(ATMEGA32U4-MU)


//---- 센서의 핀 설계
  Neopixel_Led_Pin  number is   5 
  Buzzer_pin        number is   6 (BuiltIn)
  Led_pin           number is   13(BuiltIn)
  Button_pin        number is   A0(BuiltIn)
  Soil_Sensor       number is   A1
  DHTPIN            number is   A2
  Cds               number is   A3
  Fan A_Front       number is   7       // 쿨링팬 왼쪽   A의 전진방향
  Fan A_Back        number is   4       // 쿨링팬 왼쪽   A의 후진방향
  Fan A_Front       number is   8       // 쿨링팬 오른쪽 B의 전진방향
  Fan A_Back        number is   12      // 쿨링팬 오른쪽 B의 후진방향
  TouchPins[4]      number is   {11,14,15,16}
*/

#include <Adafruit_NeoPixel.h>
#include <LiquidCrystal_I2C.h>
#include "DHT.h"

// DHT 센서 핀 정의
#define DHTPIN A2
// DHT 센서의 종류
#define DHTTYPE DHT11
// 토양 온습도 센서 핀 번호
#define Soil_Sensor A1
#define A_Front  7      // 쿨링팬 왼쪽   A의 전진방향
#define A_Back   4      // 쿨링팬 왼쪽   A의 후진방향
#define B_Front  8      // 쿨링팬 오른쪽 B의 전진방향
#define B_Back  12      // 쿨링팬 오른쪽 B의 후진방향
#define numPixels 8     // 스트립 개수
#define pixelsPin 5     // PWM 핀번호 사용
#define Buzzer_pin 6    // 멜로디 IC 또는 부저로 사용
#define Button_pin A0                 
#define Led_pin 13

// 버튼상태 변수 선언
int Button_state = 0;
int LED_state = 0;
int FAN_state = 0;
int LCD_state = 0;
int NEO_LED_state = 0;
String bluetooth_String = "";

LiquidCrystal_I2C lcd(0x27, 16, 2); 
// 정의된 핀과 센서 유형으로 dht 객체 생성
DHT dht(DHTPIN, DHTTYPE);
// (NEO_GRB + NEO_KHZ800): 색상 형식과 통신 속도를 지정
Adafruit_NeoPixel pixels(numPixels, pixelsPin, NEO_GRB + NEO_KHZ800);      

//----------------------------------------------------------------------
// 부팅시 만 실행
void setup()  {
  // 시리얼통신 초기화(9600)bps
  Serial.begin(9600);
  //블루투스 시리얼 개방
  Serial1.begin(9600);  
  // LCD 초기화 
  
  // 온습도센서를 초기화 합니다.
  dht.begin();

  pinMode(Buzzer_pin, OUTPUT); 
  pinMode(Led_pin, OUTPUT); 

  lcd.init();
  // 백라이트 활성화
  lcd.backlight();
  // LCD 화면 지우기
  lcd.clear();
  //0행 0열 커서위치
  lcd.setCursor(0,0);
  lcd.print("Hello,MetaPlace!");
  //1행 0열 커서위치
  lcd.setCursor(0,1);
  lcd.print("Happy Day!");

  pixels.begin();
  // 밝기는 0에서 255까지의 값을 가짐
  pixels.setBrightness(10); 
  pixels.clear();  
}


void loop()  {
  // Bluetooth_Rx_Tx:
  // bluetooth_Serial ASCII형식 
   if (Serial1.available())  {
    bluetooth_String = Serial1.read();   
  }
  
  // bluetooth_String 값이 있다면
  if(bluetooth_String != "")  { 
    // ASCII Code 1 = "49"
    if (bluetooth_String == "49" && LED_state==0)  {
      LED_state= 1;
      Serial.println("LED ON!");
      digitalWrite(Led_pin, HIGH);
    }

    else if(bluetooth_String == "49" && LED_state==1)  {
      LED_state= 0;
      Serial.println("LED OFF!");
      digitalWrite(Led_pin, LOW);
    }
    
    if(bluetooth_String == "50" && FAN_state==0)  {
      FAN_state= 1;
      Serial.println("FAN ON!");
      // 모터 A를 전진 방향으로 회전
      digitalWrite(A_Front, LOW);
      digitalWrite(A_Back, HIGH);
      // 모터 B를 전진 방향으로 회전
      digitalWrite(B_Front, HIGH);
      digitalWrite(B_Back, LOW);
          // BUZZER ON
    digitalWrite(Buzzer_pin, HIGH);
    Serial.println("BUZZER ON");
    }

    else if(bluetooth_String == "50" && FAN_state==1)  {
      FAN_state= 0;
      Serial.println("FAN OFF!");
      // 모터 A와 모터 B를 정지
      digitalWrite(A_Front, LOW);
      digitalWrite(A_Back, LOW);
      digitalWrite(B_Front, LOW);
      digitalWrite(B_Back, LOW);
          // BUZZER OFF
    digitalWrite(Buzzer_pin, LOW);
    Serial.println("BUZZER OFF"); 
    }

    if(bluetooth_String == "51" && LCD_state==0)  {
      LCD_state= 1;
      delay(1000);
      // h는 습도, t는 온도
      int h = dht.readHumidity();
      int t = dht.readTemperature();
      // 토양 온습도 센서의 값을 읽어옴
      int soilSensorValue = analogRead(Soil_Sensor);
      //LCD 화면 지우기
      lcd.clear();
      //0행 0열 커서위치
      lcd.setCursor(0,0);
      lcd.print("H:");
      lcd.print(h);
      lcd.print("%, ");
      //연속하여 프린트 
      lcd.print("T:");
      lcd.print(t);
      lcd.print("C");
      //1행 0열 커서위치 
      lcd.setCursor(0,1);
      lcd.print("Soil_value:");
      lcd.print(soilSensorValue);
    }

    else if(bluetooth_String == "51" && LCD_state==1)  {
      LCD_state= 0;
      // LCD 화면 지우기
      lcd.clear();
      //0행 0열 커서위치
      lcd.setCursor(0,0);
      lcd.print("Hello,MetaPlace!");
      //1행 0열 커서위치
      lcd.setCursor(0,1);
      lcd.print("Happy Day!");
    }

if(bluetooth_String == "52" && NEO_LED_state==0)  {
      NEO_LED_state = 1;
      Serial.println("Light ON!");
      for(int i=0; i<8; i++)  {
        pixels.setPixelColor(i,255,255,0);
        pixels.show();
      }
    }

    else if(bluetooth_String == "52" && NEO_LED_state==1)  {
      NEO_LED_state = 0;
      Serial.println("Light OFF!");
      for(int i=0; i<8; i++)  {
       pixels.setPixelColor(i,0,0,0);
       pixels.show();
      }
    }
    //블루투스 값을 초기화
    bluetooth_String = "";
  }
}

